@@ -1,4 +1,4 @@
-# load GOTTCHA assignments
+# load METAPHLAN assignments
 #
 
 # projects
@@ -7,7 +7,7 @@ data_file <- "../test_data/test_table_metaphlan.txt"
 
 # read em
 #
-the_list <- load_metaphlan_assignments(data_file)
+the_list <- load_edge_assignments(data_file, type = 'metaphlan')
 
 # tests
 #
@@ -18,4 +18,4 @@ expect_that(names(the_list[8]), equals("SSputum-no-RAB"))
 #
 # test the failure
 #
-expect_that(load_metaphlan_assignments("../test_data/nonexistentfile.txt"), throws_error())
+expect_that(load_edge_assignments("../test_data/nonexistentfile.txt", type = 'metaphlan'), throws_error())
