@@ -13,10 +13,10 @@ test_data_file <- file.path(test_data_folder, "test_data/test_table_gottcha.txt"
 #
 
 # [0.0]
-assignments <- load_gottcha_assignments(test_data_file)
+assignments <- load_edge_assignments(test_data_file, type = 'gottcha')
 
 # [1.0]
-merged_assignments_table <- merge_gottcha_assignments(assignments)
+merged_assignments_table <- merge_edge_assignments(assignments)
 
 # [2.0] create a folder
 #
@@ -25,9 +25,12 @@ dir.create(path = tmp_folder, recursive = TRUE, showWarnings = FALSE)
 
 # [2.1] create the pdf
 #
-gplot <- plot_merged_assignment(merged_assignments_table, "family", "abundance",
-                                60, "Test Plot #3",
-                                file.path(tmp_folder, "test_pdf3"))
+gplot <- plot_merged_assignment(assignment = merged_assignments_table,
+                                taxonomy_level = "family",
+                                sorting_order = "abundance",
+                                row_limit = 60,
+                                plot_title = "Test Plot #3",
+                                filename = file.path(tmp_folder, "test_pdf3"))
 
 # [2.2] test that file exists
 #
